==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/02/0257d715a13da579137e4af0b948acb8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Twig/Extension/AppExtension.php */
class __TwigTemplate_308dbca14f47826f50c4664571b7e715 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Twig\\Extension;

use Twig\\Extension\\AbstractExtension;
use Twig\\TwigFunction;
use Twig\\TwigTest;

class AppExtension extends AbstractExtension
{
    /**
     * @return TwigFunction[]
     */
    public function getFunctions()
    {
        return [
            new TwigFunction('ini_get', fn (\$value) => ini_get(\$value)),
            new TwigFunction('is_class', fn (string \$value) => class_exists(\$value)),
            new TwigFunction('is_file', fn (string \$value) => file_exists(\$value)),
            new TwigFunction('is_function', fn (string \$value) => function_exists(\$value)),
            new TwigFunction('is_extension_loaded', fn (string \$value) => extension_loaded(\$value)),
        ];
    }

    /**
     * @return TwigTest[]
     */
    public function getTests(): array
    {
        return [
            new TwigTest('string', fn (\$value) => is_string(\$value)),
            new TwigTest('class', fn (string \$value) => class_exists(\$value)),
            new TwigTest('file', fn (string \$value) => file_exists(\$value)),
            new TwigTest('function', fn (string \$value) => function_exists(\$value)),
        ];
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Twig/Extension/AppExtension.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Twig/Extension/AppExtension.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Twig/Extension/AppExtension.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/02/0257d715a13da579137e4af0b948acb8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Twig/Extension/AppExtension.php */
class __TwigTemplate_308dbca14f47826f50c4664571b7e715 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Twig\\Extension;

use Twig\\Extension\\AbstractExtension;
use Twig\\TwigFunction;
use Twig\\TwigTest;

class AppExtension extends AbstractExtension
{
    /**
     * @return TwigFunction[]
     */
    public function getFunctions()
    {
        return [
            new TwigFunction('ini_get', fn (\$value) => ini_get(\$value)),
            new TwigFunction('is_class', fn (string \$value) => class_exists(\$value)),
            new TwigFunction('is_file', fn (string \$value) => file_exists(\$value)),
            new TwigFunction('is_function', fn (string \$value) => function_exists(\$value)),
            new TwigFunction('is_extension_loaded', fn (string \$value) => extension_loaded(\$value)),
        ];
    }

    /**
     * @return TwigTest[]
     */
    public function getTests(): array
    {
        return [
            new TwigTest('string', fn (\$value) => is_string(\$value)),
            new TwigTest('class', fn (string \$value) => class_exists(\$value)),
            new TwigTest('file', fn (string \$value) => file_exists(\$value)),
            new TwigTest('function', fn (string \$value) => function_exists(\$value)),
        ];
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Twig/Extension/AppExtension.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Twig/Extension/AppExtension.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Twig/Extension/AppExtension.php");
    }
}
